Cheshire3 Object Model - Selector
=================================

.. _objects-selector-api:

API
---

.. autoclass:: cheshire3.baseObjects.Selector
   :members:


.. _objects-selector-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.selector.XPathSelector

.. autoclass:: cheshire3.selector.TransformerSelector

.. autoclass:: cheshire3.selector.MetadataSelector

.. autoclass:: cheshire3.selector.SpanXPathSelector
